@@ -45,6 +45,8 @@
 
 #undef KRB5
 
+#undef USE_SSL
+
 /* Define this if we're using MIT's implementation of krb5 */
 #undef KRB5_MIT
 
@@ -54,3 +56,13 @@
 #undef HAVE_LIBDES
 
 #undef HOSTTYPE
+
+#undef HAVE_U_INTXX_T
+
+#undef HAVE_UINTXX_T
+
+#undef HAVE_U_INT64_T
+
+#undef HAVE_UINT64_T
+
+#undef USE_PIPES
