@@ -1,4 +1,4 @@
-/* $Id: commands.c,v 1.12 2001/07/01 12:58:23 mhe Exp $
+/* $Id: commands.c,v 1.14 2002/02/23 13:16:30 mhe Exp $
  *
  * commands.c --
  *
@@ -217,7 +217,7 @@ void expand_alias_parameters(args_t **args, args_t *alias_args)
 			int n;
 
 			*e = 0;
-			n = strtoul(++e, &ep, 0);
+			n = strtoul(++e, &ep, 0) - 1;
 
 			if(ep != e && n < alias_args->argc && n >= 0) {
 				ins = deleted->argv[n];
@@ -752,8 +752,8 @@ void cmd_chmod(int argc, char **argv)
 	}
 
 	for(li=gl->first; li; li=li->next) {
-		ftp_chmod(((rfile *)li->data)->path, argv[optind]);
-		printf("%s: %s\n", ((rfile *)li->data)->path, ftp_getreply(false));
+		if(ftp_chmod(((rfile *)li->data)->path, argv[optind]) != 0)
+			printf("%s: %s\n", ((rfile *)li->data)->path, ftp_getreply(false));
 	}
 	rglob_destroy(gl);
 }
