@@ -1,21 +1,14 @@
-/* rfile.h -- representation of a remote file
+/* $Id: rfile.h,v 1.5 2001/05/13 13:27:00 mhe Exp $
  *
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
+ * rfile.h -- representation of a remote file
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #ifndef _rfile_h_included
@@ -56,6 +49,9 @@ void rfile_fake(rfile *f, const char *path);
 int rfile_parse(rfile *f, char *str, const char *dirpath);
 void rfile_parse_colors(rfile *f);
 
+int month_number(const char *str);
+void rfile_parse_time(rfile *f, const char *m, const char *d, const char *y);
+
 char rfile_classchar(const rfile *f);
 mode_t rfile_getmode(const rfile *f);
 
@@ -66,4 +62,6 @@ mode_t str2mode_t(const char *p);
 int rfile_search_filename(rfile *f, const char *filename);
 int rfile_search_path(rfile *f, const char *path);
 
+char *time_to_string(time_t t);
+
 #endif
