@@ -76,9 +76,6 @@ int ssh_connect(char **args, int *in, int *out, pid_t *sshpid)
 		close(c_in);
 		close(c_out);
 
-		if(ftp_get_verbosity() == vbDebug)
-			fprintf(stderr, "executing '%s'...\n", gvSSHProgram);
-
 		execv(gvSSHProgram, args);
 		ftp_err("exec: %s: %s\n", gvSSHProgram, strerror(errno));
 		exit(1);
@@ -90,58 +87,6 @@ int ssh_connect(char **args, int *in, int *out, pid_t *sshpid)
 	return 0;
 }
 
-char **ssh_make_args(char ***args, char *add_arg)
-{
-	static int nargs = 0;
-	char debug_buf[4096];
-	int i;
-
-	/* Init args array */
-	if (*args == NULL) {
-		nargs = 2;
-		i = 0;
-		*args = xmalloc(sizeof(*args) * nargs);
-		(*args)[i++] = "ssh";
-		(*args)[i++] = NULL;
-	}
-
-	/* If asked to add args, then do so and return */
-	if (add_arg) {
-		i = nargs++ - 1;
-		*args = xrealloc(*args, sizeof(*args) * nargs);
-		(*args)[i++] = add_arg;
-		(*args)[i++] = NULL;
-		return(NULL);
-	}
-
-	/* no subsystem if the server-spec contains a '/' */
-	if(gvSFTPServerProgram == NULL || strchr(gvSFTPServerProgram, '/') == NULL)
-		ssh_make_args(args, "-s");
-	ssh_make_args(args, "-oForwardX11=no");
-	ssh_make_args(args, "-oForwardAgent=no");
-	ssh_make_args(args, use_ssh1 ? "-oProtocol=1" : "-oProtocol=2");
-
-	/* Otherwise finish up and return the arg array */
-	if (gvSFTPServerProgram != NULL)
-		ssh_make_args(args, gvSFTPServerProgram);
-	else
-		ssh_make_args(args, "sftp");
-
-	/* XXX: overflow - doesn't grow debug_buf */
-	debug_buf[0] = '\0';
-	for(i = 0; (*args)[i]; i++) {
-		if(i)
-			strlcat(debug_buf, " ", sizeof(debug_buf));
-		strlcat(debug_buf, (*args)[i], sizeof(debug_buf));
-	}
-	if(ftp_get_verbosity() == vbDebug)
-		ftp_err("SSH args: '%s'\n", debug_buf);
-	else
-		ftp_trace("SSH args: '%s'\n", debug_buf);
-
-	return *args;
-}
-
 static const char *ssh_cmd2txt(int code)
 {
 	static const char *strings[] = {
@@ -253,7 +198,7 @@ static void ssh_print_reply(int code)
 int ssh_reply(Buffer *m)
 {
 	u_int len, msg_len;
-	unsigned char buf[4096];
+	char buf[4096];
 	bool reply_printed = false;
 
 	len = atomicio(read, ftp->ssh_in, buf, 4);
