@@ -1,21 +1,14 @@
-/* fxp.c -- transfer files between hosts
- * 
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
- * 
+/* $Id: fxp.c,v 1.9 2001/05/13 20:06:55 mhe Exp $
+ *
+ * fxp.c -- transfer files between hosts
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
@@ -102,7 +95,6 @@ static void fxp_preserve_attribs(const rfile *fi, char *dest)
 {
 	mode_t m = rfile_getmode(fi);
 	if(m != (mode_t)-1) {
-		/* ftp_use(fxp_target); */
 		if(ftp->has_site_chmod_command)
 			ftp_chmod(dest, get_mode_string(m));
 	}
@@ -144,7 +136,7 @@ static int do_the_fxp(Ftp *srcftp, const char *src,
 			transfer_mail_msg(_("failed to send %s: %s\n"),
 							  src, ftp_getreply(false));
 	}
-	
+
 	return r;
 }
 
@@ -184,7 +176,7 @@ static int fxpfile(const rfile *fi, unsigned int opt,
 	path_collapse(dest);
 
 	ftp_use(fxp_target);
-	
+
 	/* make sure destination directory exists */
 	dpath = base_dir_xptr(dest);
 	dest_dir = ftp_path_absolute(dpath);
@@ -228,7 +220,7 @@ static int fxpfile(const rfile *fi, unsigned int opt,
 			ftp_use(thisftp);
 			src_ft = ftp_filetime(fi->path);
 			ftp_use(fxp_target);
-			
+
 			dst_ft = ftp_filetime(dest);
 
 			if(src_ft != (time_t)-1 && dst_ft != (time_t)-1 && dst_ft >= src_ft) {
@@ -286,7 +278,7 @@ static int fxpfile(const rfile *fi, unsigned int opt,
 		bool dodel = false;
 
 		ftp_use(thisftp);
-		
+
 		if(!test(opt, FXP_FORCE)
 		   && !fxp_delbatch && !gvSighupReceived)
 			{
@@ -314,7 +306,6 @@ static int fxpfile(const rfile *fi, unsigned int opt,
 						shortpath(fi->path, 42, ftp->homedir),
 						ftp_getreply(false));
 		}
-/*		ftp_use(fxp_target);*/
 	}
 
 	ftp_use(thisftp);
@@ -391,7 +382,7 @@ static void fxpfiles(list *gl, unsigned int opt, const char *output)
 			if(strncmp(opath, lnfp->path, strlen(lnfp->path)) == 0) {
 				ftp_trace("opath == '%s', lnfp->path == '%s'\n", opath,
 						  lnfp->path);
-				fprintf(stderr, _("%s: circular link -- skipping\n"), 
+				fprintf(stderr, _("%s: circular link -- skipping\n"),
 						shortpath(lnfp->path, 42, ftp->homedir));
 				transfer_nextfile(gl, &li, true);
 				continue;
@@ -404,7 +395,7 @@ static void fxpfiles(list *gl, unsigned int opt, const char *output)
 				 */
 				goto link_to_link__duh;
 		}
-		
+
 		if(risdir(fp)) {
 			if(test(opt, FXP_RECURSIVE)) {
 				char *recurs_output;
@@ -485,7 +476,7 @@ void cmd_fxp(int argc, char **argv)
 	int ret;
 	char fxp_rx_errbuf[129];
 #endif
-	int c, opt = 0;
+	int c, opt = FXP_VERBOSE;
 	struct option longopts[] = {
 		{"append", no_argument, 0, 'a'},
 		{"delete-after", no_argument, 0, 'D'},
@@ -613,7 +604,8 @@ void cmd_fxp(int argc, char **argv)
 				break;
 			case 'o': /* --output=DIRECTORY */
 				if(fxp_target == 0) {
-					printf(_("FxP target not set, use --target=NAME (as first option)\n"));
+					printf(_("FxP target not set, use --target=NAME"
+							 " (as first option)\n"));
 					return;
 				}
 				fxp_output = tilde_expand_home(optarg, fxp_target->homedir);
@@ -673,15 +665,21 @@ void cmd_fxp(int argc, char **argv)
 		minargs(optind);
 		return;
 	}
-	
+
 	need_connected();
 	need_loggedin();
 
 	if(fxp_target == 0) {
-		ftp_err(_("No target specified, try '%s --help' for more information\n"), argv[0]);
+		ftp_err(_("No target specified, try '%s --help'"
+				  " for more information\n"), argv[0]);
 		return;
 	}
-	
+
+	if(ftp->ssh_pid || fxp_target->ssh_pid) {
+		ftp_err("FxP for SSH connections no implemented\n");
+		return;
+	}
+
 	gl = rglob_create();
 	while(optind < argc) {
 		stripslash(argv[optind]);
